"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.create = void 0;
const fs_extra_1 = require("fs-extra");
const http_1 = require("http");
const next_1 = require("../../../next");
const options_1 = require("../../../options");
const constants_1 = require("../../../../../constants");
const logger_1 = require("../../../../../logger");
const utils_1 = require("../utils");
const options_2 = require("../../../../../utils/options");
const utils_2 = require("../../../../../utils/utils");
const getLogger = () => (0, logger_1.get)("commands.handler.authentication.oauth.tokenProvider.getToken");
const retrieveCode = async () => new Promise((resolve, reject) => {
    const PORT = parseInt(process.env.CLI_HTTP_PORT || "8080", 10);
    const { debug } = getLogger();
    let timeout;
    const server = (0, http_1.createServer)(async (req, res) => {
        clearTimeout(timeout);
        const code = new URL(req.url ? `http://localhost:${PORT}${req.url}` : "http://no-code.damn").searchParams.get("code");
        let file;
        try {
            file = await (0, fs_extra_1.readFile)(code ? constants_1.PATH_TO_SUCCESS_HTML : constants_1.PATH_TO_ERROR_HTML, "utf8");
        }
        catch (err) {
            debug("failed to read file for code", code, err);
            file =
                "<html><body>Ops, something went wrong! Please try again.</body></html>";
        }
        res.writeHead(200, {
            "Content-Type": "text/html",
            "Content-Security-Policy": "frame-ancestors 'none'",
            "X-Frame-Options": "DENY",
        });
        res.end(file, "utf8");
        server.close();
        if (code) {
            resolve(code);
        }
        else {
            reject(new Error("no code found in callback URI"));
        }
    });
    timeout = setTimeout(() => {
        server.close();
        reject(new Error("Did not receive a code within 30 seconds"));
    }, 30 * 1000);
    server.listen(PORT);
    debug(`started http server at localhost:${PORT}`);
});
const getCode = async (authorizeUrl, clientId) => {
    const { debug } = getLogger();
    try {
        return (0, options_2.getOptionValueFromConfig)(constants_1.OPTION_CODE);
    }
    catch (err) {
        debug("failed to retrieve code from options", err);
        return (await Promise.all([
            retrieveCode(),
            (0, utils_2.openUrlInBrowser)(authorizeUrl, {
                response_type: "code",
                client_id: clientId,
            }),
        ]))[0];
    }
};
const handler = () => async () => {
    const { info: logInfo, debug } = getLogger();
    logInfo("checking token existence");
    const secrets = (0, utils_1.getSecrets)();
    if (!secrets.access_token && !secrets.refresh_token) {
        debug("access token not available, retrieving token from server");
        const code = await getCode(secrets.authorization_url, secrets.client_id);
        await (0, utils_1.readToken)({
            code,
            grant_type: "authorization_code",
        });
        await (0, utils_1.storeSecrets)();
    }
    else if (secrets.access_token) {
        debug("token available");
    }
    else {
        throw new Error("access token not available");
    }
};
const create = () => (0, next_1.create)((0, options_1.create)(constants_1.OPTION_CODE), handler);
exports.create = create;
