"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.refreshToken = void 0;
const logger_1 = require("../../../../../logger");
const utils_1 = require("../utils");
const setAuthorization_1 = require("./setAuthorization");
const refreshToken = async (forceRefresh = false) => {
    const { info: logInfo, debug } = (0, logger_1.get)("commands.handler.authentication.oauth.tokenProvider.utils.refreshToken");
    const secrets = (0, utils_1.getSecrets)();
    if ((!forceRefresh && !secrets.expires_after) || !secrets.refresh_token) {
        throw new Error("invalid secrets information");
    }
    logInfo("checking token expiry date");
    if (forceRefresh || (0, utils_1.isExpired)(secrets.expires_after)) {
        debug("access token is expired, refreshing token");
        await (0, utils_1.readToken)({
            refresh_token: secrets.refresh_token,
            grant_type: "refresh_token",
        });
        await (0, utils_1.storeSecrets)();
        await (0, setAuthorization_1.updateAuthorization)();
    }
    else {
        debug("access token is not expired");
    }
};
exports.refreshToken = refreshToken;
