"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.readToken = exports.isExpired = exports.calculateExpiresAfter = exports.storeSecrets = exports.getSecrets = exports.setSecrets = void 0;
const qs_1 = __importDefault(require("qs"));
const cache_1 = require("../../../../cache");
const config_1 = require("../../../../config");
const constants_1 = require("../../../../constants");
const http_1 = require("../../../../utils/http");
const setSecrets = (info) => {
    (0, config_1.set)({ oauth: info });
};
exports.setSecrets = setSecrets;
const getSecrets = () => {
    const { oauth } = (0, config_1.get)();
    if (oauth) {
        return oauth;
    }
    throw new Error("no secrets exist");
};
exports.getSecrets = getSecrets;
const storeSecrets = async () => {
    await (0, cache_1.writeFile)(constants_1.CACHE_SECRETS_FILE, JSON.stringify((0, exports.getSecrets)()));
};
exports.storeSecrets = storeSecrets;
const calculateExpiresAfter = (expires_in) => Math.floor(Date.now() / 1000) + expires_in - 10;
exports.calculateExpiresAfter = calculateExpiresAfter;
const isExpired = (expires_after) => expires_after <= (0, exports.calculateExpiresAfter)(10);
exports.isExpired = isExpired;
const readToken = async (data) => {
    const secrets = (0, exports.getSecrets)();
    if (!secrets.token_url || !secrets.client_id || !secrets.client_secret) {
        throw new Error("invalid secrets information");
    }
    const info = (await (0, http_1.fetch)({
        method: "POST",
        url: secrets.token_url,
        auth: {
            username: secrets.client_id,
            password: secrets.client_secret,
        },
        headers: {
            "x-sap-sac-custom-auth": true,
            "content-type": "application/x-www-form-urlencoded",
        },
        data: qs_1.default.stringify({
            ...data,
            response_type: "token",
        }),
    })).data;
    (0, exports.setSecrets)({
        ...info,
        expires_after: (0, exports.calculateExpiresAfter)(info.expires_in),
    });
};
exports.readToken = readToken;
