"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.create = void 0;
const logger_1 = require("../../logger");
const getLogger = () => (0, logger_1.get)("commands.handlers.or");
const create = (...handlers) => {
    const { stack } = new Error();
    return (command) => {
        const commandHandlers = [];
        for (const handler of handlers) {
            commandHandlers.push(handler(command));
        }
        return async (...args) => {
            const { debug, trace } = getLogger();
            let handlerFailed = false;
            for (const handler of commandHandlers) {
                handlerFailed = false;
                try {
                    // eslint-disable-next-line
                    await handler(...args);
                    trace(`handler succeeded, exiting loop`);
                    break;
                }
                catch (err) {
                    debug(`handler failed`, err.stack || err);
                    handlerFailed = true;
                }
            }
            if (handlerFailed) {
                trace("handler was created from:", stack);
                throw new Error("all handlers failed");
            }
        };
    };
};
exports.create = create;
/* jscpd:ignore-end */
