"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getOptionValueFromArgv = exports.compareEtags = exports.checkVersion = void 0;
const logger_1 = require("../logger");
const discovery_1 = require("../discovery");
const commands_1 = require("../utils/commands");
const core_1 = require("../config/core");
const getLogger = () => (0, logger_1.get)("dwc.utils");
const checkVersion = async () => {
    const { output, error } = getLogger();
    try {
        const result = await (0, discovery_1.checkVersion)();
        if (result.status === "OUTDATED") {
            output(`Your local CLI installation is outdated. Run 'npm install ${(0, core_1.getPackageName)()} [-g]' to update`);
        }
    }
    catch (err) {
        error(err.stack);
    }
};
exports.checkVersion = checkVersion;
const compareEtags = async () => {
    if (!(await (0, discovery_1.compareEtags)())) {
        const { output } = getLogger();
        output(`Your local CLI cache is outdated. Run 'dwc cache init' to update`);
    }
};
exports.compareEtags = compareEtags;
const getOptionValueFromArgv = ({ longName }) => {
    const shortFlag = (0, commands_1.getShortFlagForLongName)(longName);
    const index = process.argv.findIndex((a) => a === `-${shortFlag}` || a === `--${longName}`);
    if (index > -1) {
        return process.argv[index + 1];
    }
    throw new Error(`option ${longName} not found in argv`);
};
exports.getOptionValueFromArgv = getOptionValueFromArgv;
